#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ACOTD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ACOTD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/acotd.hpp>

#endif
